@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2020, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2.0, as published by the
@@ -29,8 +29,8 @@
 
 package com.mysql.cj.result;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
@@ -38,7 +38,7 @@ import java.time.DateTimeException;
 import java.time.LocalDate;
 import java.util.concurrent.Callable;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.mysql.cj.MysqlType;
 import com.mysql.cj.conf.DefaultPropertySet;
@@ -66,13 +66,7 @@ public class LocalDateValueFactoryTest extends CommonAsserts {
 
     @Test
     public void testCreateFromTime() {
-        assertThrows(DataConversionException.class, "Unsupported conversion from TIME to java.time.LocalDate", new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-                LocalDateValueFactoryTest.this.vf.createFromTime(new InternalTime(-1, 0, 0, 0, 0));
-                return null;
-            }
-        });
+        assertEquals(LocalDate.of(1970, 1, 1), this.vf.createFromTime(new InternalTime(-1, 0, 0, 0, 0)));
     }
 
     @Test
@@ -194,14 +188,7 @@ public class LocalDateValueFactoryTest extends CommonAsserts {
 
         assertEquals(LocalDate.of(2018, 1, 2), this.vf.createFromBytes("2018-01-02 03:04:05.6".getBytes(), 0, 21, f));
         assertEquals(LocalDate.of(2018, 1, 2), this.vf.createFromBytes("2018-01-02".getBytes(), 0, 10, f));
-
-        assertThrows(DataConversionException.class, "Unsupported conversion from TIME to java.time.LocalDate", new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-                LocalDateValueFactoryTest.this.vf.createFromBytes("03:04:05.6".getBytes(), 0, 10, f);
-                return null;
-            }
-        });
+        assertEquals(LocalDate.of(1970, 1, 1), this.vf.createFromBytes("03:04:05.6".getBytes(), 0, 10, f));
 
         assertThrows(DataConversionException.class, "Cannot convert string '1' to java.time.LocalDate value", new Callable<Void>() {
             @Override
