@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2021, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, version 2.0, as published by the
@@ -29,16 +29,16 @@
 
 package com.mysql.cj.xdevapi;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.mysql.cj.exceptions.WrongArgumentException;
 import com.mysql.cj.x.protobuf.MysqlxCrud.Column;
@@ -58,15 +58,14 @@ public class ExprParserTest {
 
     /**
      * Check that a string doesn't parse.
+     * 
+     * @param s
      */
     private void checkBadParse(String s) {
-        try {
+        assertThrows(WrongArgumentException.class, () -> {
             Expr e = new ExprParser(s).parse();
             System.err.println("Parsed as: " + e);
-            fail("Expected exception while parsing: '" + s + "'");
-        } catch (WrongArgumentException ex) {
-            // expected
-        }
+        }, "Expected exception while parsing: '" + s + "'");
     }
 
     @Test
@@ -109,6 +108,9 @@ public class ExprParserTest {
 
     /**
      * Check that a string parses and is reconstituted as a string that we expect. Futher we parse the canonical version to make sure it doesn't change.
+     * 
+     * @param input
+     * @param expected
      */
     private void checkParseRoundTrip(String input, String expected) {
         if (expected == null) {
